@@ -392,10 +392,10 @@ clean_parameters.aovlist <- function(x, ...) {
 
 #' @export
 clean_parameters.afex_aov <- function(x, ...) {
-  if (!is.null(x$aov)) {
-    clean_parameters(x$aov, ...)
-  } else {
+  if (is.null(x$aov)) {
     clean_parameters(x$lm, ...)
+  } else {
+    clean_parameters(x$aov, ...)
   }
 }
 
@@ -497,22 +497,22 @@ clean_parameters.mlm <- function(x, ...) {
 
     resp_pattern <- sprintf("_%s_(.*)", resp)
     for (i in resp_pattern) {
-      out$Cleaned_Parameter <- gsub(pattern = i, "_\\1", out$Cleaned_Parameter, perl = TRUE)
+      out$Cleaned_Parameter <- gsub(pattern = i, "_\\1", out$Cleaned_Parameter)
     }
 
     resp_pattern <- sprintf("__%s(.*)", resp)
     for (i in resp_pattern) {
-      out$Cleaned_Parameter <- gsub(pattern = i, "\\1", out$Cleaned_Parameter, perl = TRUE)
+      out$Cleaned_Parameter <- gsub(pattern = i, "\\1", out$Cleaned_Parameter)
     }
 
     resp_pattern <- sprintf("__zi_%s(.*)", resp)
     for (i in resp_pattern) {
-      out$Cleaned_Parameter <- gsub(pattern = i, "\\1", out$Cleaned_Parameter, perl = TRUE)
+      out$Cleaned_Parameter <- gsub(pattern = i, "\\1", out$Cleaned_Parameter)
     }
 
     resp_pattern <- sprintf("(sigma)(_%s)", resp)
     for (i in resp_pattern) {
-      out$Cleaned_Parameter <- gsub(pattern = i, "\\1", out$Cleaned_Parameter, perl = TRUE)
+      out$Cleaned_Parameter <- gsub(pattern = i, "\\1", out$Cleaned_Parameter)
     }
   }
 
@@ -526,20 +526,20 @@ clean_parameters.mlm <- function(x, ...) {
   # clean fixed effects, conditional and zero-inflated
 
   out$Cleaned_Parameter <- gsub(pattern = "^b_(?!zi_)(.*)\\.(\\d)\\.$", "\\1[\\2]", out$Cleaned_Parameter, perl = TRUE)
-  out$Cleaned_Parameter <- gsub(pattern = "^b_zi_(.*)\\.(\\d)\\.$", "\\1[\\2]", out$Cleaned_Parameter, perl = TRUE)
+  out$Cleaned_Parameter <- gsub(pattern = "^b_zi_(.*)\\.(\\d)\\.$", "\\1[\\2]", out$Cleaned_Parameter)
   out$Cleaned_Parameter <- gsub(pattern = "^(b_|bs_|bsp_|bcs_)(?!zi_)(.*)", "\\2", out$Cleaned_Parameter, perl = TRUE)
-  out$Cleaned_Parameter <- gsub(pattern = "^(b_zi_|bs_zi_|bsp_zi_|bcs_zi_)(.*)", "\\2", out$Cleaned_Parameter, perl = TRUE)
+  out$Cleaned_Parameter <- gsub(pattern = "^(b_zi_|bs_zi_|bsp_zi_|bcs_zi_)(.*)", "\\2", out$Cleaned_Parameter) # nolint
 
   # correlation and sd
 
   cor_sd <- grepl("(sd_|cor_)(.*)", out$Cleaned_Parameter)
   if (any(cor_sd)) {
-    out$Cleaned_Parameter[cor_sd] <- gsub("^(sd_|cor_)(.*?)__(.*)", "\\3", out$Parameter[cor_sd], perl = TRUE)
-    out$Group[cor_sd] <- paste("SD/Cor:", gsub("^(sd_|cor_)(.*?)__(.*)", "\\2", out$Parameter[cor_sd], perl = TRUE))
+    out$Cleaned_Parameter[cor_sd] <- gsub("^(sd_|cor_)(.*?)__(.*)", "\\3", out$Parameter[cor_sd])
+    out$Group[cor_sd] <- paste("SD/Cor:", gsub("^(sd_|cor_)(.*?)__(.*)", "\\2", out$Parameter[cor_sd]))
     # replace "__" by "~"
     cor_only <- startsWith(out$Parameter[cor_sd], "cor_")
     if (any(cor_only)) {
-      out$Cleaned_Parameter[which(cor_sd)[cor_only]] <- sub("__", " ~ ", out$Cleaned_Parameter[which(cor_sd)[cor_only]], fixed = TRUE)
+      out$Cleaned_Parameter[which(cor_sd)[cor_only]] <- sub("__", " ~ ", out$Cleaned_Parameter[which(cor_sd)[cor_only]], fixed = TRUE) # nolint
     }
   }
 
@@ -552,9 +552,7 @@ clean_parameters.mlm <- function(x, ...) {
     # for backwards compatibility, we keep the old behaviour. But generally,
     # when we have the argument "version = 2", Stan models have the same
     # labelling as frequentist models
-    if (!identical(dots$version, 2)) {
-      r_grps <- gsub("^r_(.*)\\[(.*),(.*)\\]", "\\3: \\1", out$Cleaned_Parameter[rand_eff])
-    } else {
+    if (identical(dots$version, 2)) {
       out$Level <- ""
       r_levels <- gsub("^r_(.*)\\[(.*),(.*)\\]", "\\2", out$Cleaned_Parameter[rand_eff])
       r_grps <- gsub("^r_(.*)\\[(.*),(.*)\\]", "\\1", out$Cleaned_Parameter[rand_eff])
@@ -567,6 +565,8 @@ clean_parameters.mlm <- function(x, ...) {
       if (any(sd_cor)) {
         out$Group[sd_cor] <- gsub("SD/Cor: (.*)", "\\1", out$Group[sd_cor])
       }
+    } else {
+      r_grps <- gsub("^r_(.*)\\[(.*),(.*)\\]", "\\3: \\1", out$Cleaned_Parameter[rand_eff])
     }
     r_pars <- gsub("__zi", "", r_pars, fixed = TRUE)
     r_grps <- gsub("__zi", "", r_grps, fixed = TRUE)
@@ -585,15 +585,15 @@ clean_parameters.mlm <- function(x, ...) {
 
   simplex <- startsWith(out$Cleaned_Parameter, "simo_")
   if (length(simplex)) {
-    out$Cleaned_Parameter[simplex] <- gsub("^(simo_|simo_mo)(.*)\\[(\\d)\\]$", "\\2[\\3]", out$Cleaned_Parameter[simplex])
+    out$Cleaned_Parameter[simplex] <- gsub("^(simo_|simo_mo)(.*)\\[(\\d)\\]$", "\\2[\\3]", out$Cleaned_Parameter[simplex]) # nolint
     out$Component[simplex] <- "simplex"
   }
 
-  smooth <- startsWith(out$Cleaned_Parameter, "sds_")
-  if (length(smooth)) {
+  smooth_parameters <- startsWith(out$Cleaned_Parameter, "sds_")
+  if (length(smooth_parameters)) {
     out$Cleaned_Parameter <- gsub("^sds_", "", out$Cleaned_Parameter)
-    out$Component[smooth] <- "smooth_sd"
-    out$Function[smooth] <- "smooth"
+    out$Component[smooth_parameters] <- "smooth_sd"
+    out$Function[smooth_parameters] <- "smooth"
   }
 
   # fix intercept names
@@ -604,7 +604,7 @@ clean_parameters.mlm <- function(x, ...) {
     out$Cleaned_Parameter[intercepts] <- "(Intercept)"
   }
 
-  interaction_terms <- which(grepl(".", out$Cleaned_Parameter, fixed = TRUE))
+  interaction_terms <- grep(".", out$Cleaned_Parameter, fixed = TRUE)
 
   if (length(interaction_terms)) {
     for (i in interaction_terms) {
@@ -645,14 +645,14 @@ clean_parameters.mlm <- function(x, ...) {
   cor_sd <- startsWith(out$Cleaned_Parameter, "Sigma[")
 
   if (any(cor_sd)) {
-    parm1 <- gsub("^Sigma\\[(.*):(.*),(.*)\\]", "\\2", out$Parameter[cor_sd], perl = TRUE)
-    parm2 <- gsub("^Sigma\\[(.*):(.*),(.*)\\]", "\\3", out$Parameter[cor_sd], perl = TRUE)
+    parm1 <- gsub("^Sigma\\[(.*):(.*),(.*)\\]", "\\2", out$Parameter[cor_sd])
+    parm2 <- gsub("^Sigma\\[(.*):(.*),(.*)\\]", "\\3", out$Parameter[cor_sd])
     out$Cleaned_Parameter[which(cor_sd)] <- parm1
     rand_cor <- parm1 != parm2
     if (any(rand_cor)) {
       out$Cleaned_Parameter[which(cor_sd)[rand_cor]] <- paste0(parm1[rand_cor], " ~ ", parm2[rand_cor])
     }
-    out$Group[cor_sd] <- paste("SD/Cor:", gsub("^Sigma\\[(.*):(.*),(.*)\\]", "\\1", out$Parameter[cor_sd], perl = TRUE))
+    out$Group[cor_sd] <- paste("Var/Cov:", gsub("^Sigma\\[(.*):(.*),(.*)\\]", "\\1", out$Parameter[cor_sd]))
   }
 
 
@@ -662,21 +662,21 @@ clean_parameters.mlm <- function(x, ...) {
 
   if (any(rand_effects)) {
     r_pars <- gsub("b\\[(.*) (.*)\\]", "\\2", out$Cleaned_Parameter[rand_effects])
-    if (!identical(dots$version, 2)) {
-      re_grp_level <- gsub("b\\[(.*) (.*):(.*)\\]", "\\2", out$Cleaned_Parameter[rand_effects])
-      r_grps <- gsub("b\\[(.*) (.*)\\]", "\\1", out$Cleaned_Parameter[rand_effects])
-      out$Group[rand_effects] <- sprintf("%s: %s", r_grps, re_grp_level)
-    } else {
+    if (identical(dots$version, 2)) {
       out$Level <- ""
       r_levels <- gsub("b\\[(.*) (.*):(.*)\\]", "\\3", out$Cleaned_Parameter[rand_effects])
       r_grps <- gsub("b\\[(.*) (.*):(.*)\\]", "\\2", out$Cleaned_Parameter[rand_effects])
       out$Group[rand_effects] <- r_grps
       out$Level[rand_effects] <- r_levels
       # fix labelling of SD and correlation component
-      sd_cor <- grepl("SD/Cor:", out$Group, fixed = TRUE)
+      sd_cor <- grepl("Var/Cov:", out$Group, fixed = TRUE)
       if (any(sd_cor)) {
-        out$Group[sd_cor] <- gsub("SD/Cor: (.*)", "\\1", out$Group[sd_cor])
+        out$Group[sd_cor] <- gsub("Var/Cov: (.*)", "\\1", out$Group[sd_cor])
       }
+    } else {
+      re_grp_level <- gsub("b\\[(.*) (.*):(.*)\\]", "\\2", out$Cleaned_Parameter[rand_effects])
+      r_grps <- gsub("b\\[(.*) (.*)\\]", "\\1", out$Cleaned_Parameter[rand_effects])
+      out$Group[rand_effects] <- sprintf("%s: %s", r_grps, re_grp_level)
     }
 
     out$Cleaned_Parameter[rand_effects] <- r_pars
@@ -684,12 +684,12 @@ clean_parameters.mlm <- function(x, ...) {
 
   # clean remaining parameters
 
-  smooth <- startsWith(out$Cleaned_Parameter, "smooth_sd[")
+  smooth_parameters <- startsWith(out$Cleaned_Parameter, "smooth_sd[")
 
-  if (length(smooth)) {
+  if (length(smooth_parameters)) {
     out$Cleaned_Parameter <- gsub("^smooth_sd\\[(.*)\\]", "\\1", out$Cleaned_Parameter)
-    out$Component[smooth] <- "smooth_sd"
-    out$Function[smooth] <- "smooth"
+    out$Component[smooth_parameters] <- "smooth_sd"
+    out$Function[smooth_parameters] <- "smooth"
   }
 
   out
@@ -705,25 +705,23 @@ clean_parameters.mlm <- function(x, ...) {
   }
 
   out$Cleaned_Parameter <- tryCatch(
-    {
-      apply(pars, 1, function(i) {
-        if (i[1] == i[2]) {
-          i[2] <- ""
-        } else if (i[1] != i[2] && !grepl(":", i[1], fixed = TRUE)) {
-          i[1] <- paste0(i[1], " [", i[2], "]")
-          i[2] <- ""
-        } else if (grepl(":", i[1], fixed = TRUE)) {
-          f <- unlist(strsplit(i[1], ":", fixed = TRUE), use.names = FALSE)
-          l <- unlist(strsplit(i[2], ".&.", fixed = TRUE), use.names = FALSE)
-          m <- match(f, l)
-          matches <- m[!is.na(m)]
-          l[matches] <- ""
-          l[-matches] <- paste0("[", l[-matches], "]")
-          i[1] <- paste0(f, l, collapse = " * ")
-        }
-        as.vector(i[1])
-      })
-    },
+    apply(pars, 1, function(i) {
+      if (i[1] == i[2]) {
+        i[2] <- ""
+      } else if (i[1] != i[2] && !grepl(":", i[1], fixed = TRUE)) {
+        i[1] <- paste0(i[1], " [", i[2], "]")
+        i[2] <- ""
+      } else if (grepl(":", i[1], fixed = TRUE)) {
+        f <- unlist(strsplit(i[1], ":", fixed = TRUE), use.names = FALSE)
+        l <- unlist(strsplit(i[2], ".&.", fixed = TRUE), use.names = FALSE)
+        m <- match(f, l)
+        matches <- m[!is.na(m)]
+        l[matches] <- ""
+        l[-matches] <- paste0("[", l[-matches], "]")
+        i[1] <- paste0(f, l, collapse = " * ")
+      }
+      as.vector(i[1])
+    }),
     error = function(e) {
       out$Cleaned_Parameter
     }
