@@ -170,7 +170,6 @@ find_algorithm.speedlm <- function(x, ...) {
 
 #' @export
 find_algorithm.blavaan <- function(x, ...) {
-  # installed?
   check_if_installed("blavaan")
 
   list(
@@ -192,6 +191,12 @@ find_algorithm.rq <- function(x, ...) {
   list(algorithm = x$method)
 }
 
+#' @export
+find_algorithm.rqs <- find_algorithm.rq
+
+#' @export
+find_algorithm.rqss <- find_algorithm.rq
+
 
 #' @export
 find_algorithm.bayesx <- function(x, ...) {
@@ -209,12 +214,6 @@ find_algorithm.crq <- function(x, ...) {
 }
 
 
-#' @export
-find_algorithm.rqss <- function(x, ...) {
-  list(algorithm = x$method)
-}
-
-
 #' @export
 find_algorithm.glm <- function(x, ...) {
   list(algorithm = "ML")
