@@ -2,30 +2,32 @@
 #' @name find_parameters.averaging
 #'
 #' @description Returns the names of model parameters, like they typically
-#'     appear in the `summary()` output.
+#' appear in the `summary()` output.
 #'
 #' @param ... Currently not used.
 #' @inheritParams find_parameters
 #' @inheritParams find_parameters.betamfx
 #' @inheritParams find_predictors
 #'
-#' @return A list of parameter names. The returned list may have following
-#'   elements:
-#'    \itemize{
-#'      \item `conditional`, the "fixed effects" part from the model.
-#'      \item `full`, parameters from the full model.
-#'    }
+#' @inheritSection find_predictors Model components
 #'
-#' @examples
-#' data(mtcars)
-#' m <- lm(mpg ~ wt + cyl + vs, data = mtcars)
+#' @return A list of parameter names. The returned list may have following
+#' elements, usually requested via the `component` argument:
+#'
+#' - `conditional`, the "fixed effects" part from the model.
+#' - `full`, parameters from the full model.
+#' - `precision` for models of class `betareg`.
+#' - `survival` for model of class `mjoint`.
+#' - `extra` for models of class `glmx`.
+#'
+#' @examplesIf requireNamespace("betareg", quietly = TRUE)
+#' data("GasolineYield", package = "betareg")
+#' m <- betareg::betareg(yield ~ batch + temp, data = GasolineYield)
 #' find_parameters(m)
+#' find_parameters(m, component = "precision")
 #' @export
-find_parameters.averaging <- function(x,
-                                      component = c("conditional", "full"),
-                                      flatten = FALSE,
-                                      ...) {
-  component <- match.arg(component)
+find_parameters.averaging <- function(x, component = "conditional", flatten = FALSE, ...) {
+  component <- validate_argument(component, c("conditional", "full"))
   cf <- stats::coef(x, full = component == "full")
   out <- list(conditional = text_remove_backticks(names(cf)))
 
@@ -37,14 +39,37 @@ find_parameters.averaging <- function(x,
 }
 
 
-
-#' @rdname find_parameters.averaging
 #' @export
-find_parameters.betareg <- function(x,
-                                    component = c("all", "conditional", "precision", "location", "distributional", "auxiliary"),
-                                    flatten = FALSE,
-                                    ...) {
-  component <- match.arg(component)
+find_parameters.glmgee <- function(x, component = "all", flatten = FALSE, ...) {
+  component <- validate_argument(component, c("all", "conditional", "dispersion"))
+
+  junk <- utils::capture.output({
+    cs <- suppressWarnings(stats::coef(summary(x, corr = FALSE)))
+  })
+  params <- compact_character(rownames(cs))
+
+  out <- list(
+    conditional = text_remove_backticks(params[params != "Dispersion"]),
+    dispersion = text_remove_backticks(params[params == "Dispersion"])
+  )
+
+  .filter_parameters(
+    out,
+    effects = "all",
+    component = component,
+    flatten = flatten,
+    recursive = FALSE
+  )
+}
+
+
+#' @export
+find_parameters.betareg <- function(x, component = "all", flatten = FALSE, ...) {
+  component <- validate_argument(
+    component,
+    c("all", "conditional", "precision", "location", "distributional", "auxiliary")
+  )
+
   pars <- list(
     conditional = names(x$coefficients$mean),
     precision = names(x$coefficients$precision)
@@ -61,14 +86,12 @@ find_parameters.betareg <- function(x,
 }
 
 
-
-#' @rdname find_parameters.averaging
 #' @export
-find_parameters.DirichletRegModel <- function(x,
-                                              component = c("all", "conditional", "precision", "location", "distributional", "auxiliary"),
-                                              flatten = FALSE,
-                                              ...) {
-  component <- match.arg(component)
+find_parameters.DirichletRegModel <- function(x, component = "all", flatten = FALSE, ...) {
+  component <- validate_argument(
+    component,
+    c("all", "conditional", "precision", "location", "distributional", "auxiliary")
+  )
   if (x$parametrization == "common") {
     pars <- list(conditional = names(unlist(stats::coef(x))))
   } else {
@@ -91,14 +114,9 @@ find_parameters.DirichletRegModel <- function(x,
 }
 
 
-
-#' @rdname find_parameters.averaging
 #' @export
-find_parameters.mjoint <- function(x,
-                                   component = c("all", "conditional", "survival"),
-                                   flatten = FALSE,
-                                   ...) {
-  component <- match.arg(component)
+find_parameters.mjoint <- function(x, component = "all", flatten = FALSE, ...) {
+  component <- validate_argument(component, c("all", "conditional", "survival"))
   s <- summary(x)
 
   out <- list(
@@ -116,13 +134,9 @@ find_parameters.mjoint <- function(x,
 }
 
 
-
-#' @rdname find_parameters.averaging
 #' @export
-find_parameters.glmx <- function(x,
-                                 component = c("all", "conditional", "extra"),
-                                 flatten = FALSE,
-                                 ...) {
+find_parameters.glmx <- function(x, component = "all", flatten = FALSE, ...) {
+  component <- validate_argument(component, c("all", "conditional", "extra"))
   cf <- stats::coef(summary(x))
 
   out <- list(
@@ -140,18 +154,16 @@ find_parameters.glmx <- function(x,
 }
 
 
-
 #' @export
 find_parameters.model_fit <- function(x, flatten = FALSE, ...) {
   find_parameters(x$fit, flatten = flatten, ...)
 }
 
 
-
 #' @export
 find_parameters.systemfit <- function(x, flatten = FALSE, ...) {
   cf <- stats::coef(x)
-  f <- find_formula(x)
+  f <- find_formula(x, verbose = FALSE)
 
   system_names <- names(f)
 
@@ -171,7 +183,6 @@ find_parameters.systemfit <- function(x, flatten = FALSE, ...) {
 }
 
 
-
 #' @export
 find_parameters.bfsl <- function(x, flatten = FALSE, ...) {
   cf <- stats::coef(x)
@@ -232,3 +243,34 @@ find_parameters.deltaMethod <- function(x, flatten = FALSE, ...) {
     out
   }
 }
+
+
+#' @export
+find_parameters.coxph <- function(x, flatten = FALSE, ...) {
+  cf <- stats::coef(summary(x))
+  out <- list(conditional = rownames(cf))
+
+  if (flatten) {
+    unique(unlist(out, use.names = FALSE))
+  } else {
+    out
+  }
+}
+
+
+#' @export
+find_parameters.asym <- function(x, flatten = FALSE, ...) {
+  cf <- stats::coef(x)
+
+  params <- names(cf)
+  params <- gsub("^plus__", "+", params)
+  params <- gsub("^minus__", "-", params)
+
+  out <- list(conditional = params)
+
+  if (flatten) {
+    unique(unlist(out, use.names = FALSE))
+  } else {
+    out
+  }
+}
