@@ -19,6 +19,11 @@
 #' find_statistic(m)
 #' @export
 find_statistic <- function(x, ...) {
+  UseMethod("find_statistic")
+}
+
+#' @export
+find_statistic.default <- function(x, ...) {
   # model object check --------------------------------------------------------
 
   # check if the object is a model object; if not, quit early
@@ -86,6 +91,7 @@ find_statistic <- function(x, ...) {
   # t-value objects ----------------------------------------------------------
 
   t.mods <- c(
+    "asym",
     "bayesx", "BBreg", "BBmm", "bcplm", "biglm", "bfsl", "blmerMod",
     "cch", "censReg", "complmrob", "cpglm", "cpglmm", "crq", "crqs",
     "drc",
