@@ -7,22 +7,26 @@
 #' @inheritParams find_predictors
 #' @inheritParams find_formula
 #'
-#' @note The difference to [find_terms()] is that
-#'   `find_variables()` returns each variable name only once, while
-#'   `find_terms()` may return a variable multiple times in case of
-#'   transformations or when arithmetic expressions were used in the formula.
+#' @note The difference to [`find_terms()`] is that `find_variables()` returns
+#'   each variable name only once, while `find_terms()` may return a variable
+#'   multiple times in case of transformations or when arithmetic expressions
+#'   were used in the formula.
 #'
 #' @inheritSection find_predictors Model components
 #'
+#' @inheritSection find_predictors Parameters, Variables, Predictors and Terms
+#'
 #' @return A list with (depending on the model) following elements (character
 #'    vectors):
 #' - `response`, the name of the response variable
-#' - `conditional`, the names of the predictor variables from the *conditional* model (as opposed to the zero-inflated part of a model)
+#' - `conditional`, the names of the predictor variables from the *conditional*
+#'   model (as opposed to the zero-inflated part of a model)
 #' - `cluster`, the names of cluster or grouping variables
 #' - `dispersion`, the name of the dispersion terms
 #' - `instruments`, the names of instrumental variables
 #' - `random`, the names of the random effects (grouping factors)
-#' - `zero_inflated`, the names of the predictor variables from the *zero-inflated* part of the model
+#' - `zero_inflated`, the names of the predictor variables from the
+#'   *zero-inflated* part of the model
 #' - `zero_inflated_random`, the names of the random effects (grouping factors)
 #'
 #' @examplesIf require("lme4", quietly = TRUE)
@@ -57,8 +61,14 @@ find_variables <- function(x,
                            component = "all",
                            flatten = FALSE,
                            verbose = TRUE) {
-  effects <- match.arg(effects, choices = c("all", "fixed", "random"))
-  component <- match.arg(component, choices = c("all", "conditional", "zi", "zero_inflated", "dispersion", "instruments", "smooth_terms"))
+  effects <- validate_argument(effects, c("all", "fixed", "random"))
+  component <- validate_argument(
+    component,
+    c(
+      "all", "conditional", "zi", "zero_inflated", "dispersion",
+      "instruments", "smooth_terms", "scale"
+    )
+  )
 
   if (component %in% c("all", "conditional")) {
     resp <- find_response(x, combine = FALSE)
