@@ -34,6 +34,8 @@
 #' @param style_negative  A string that determines the style of negative numbers.
 #'   May be `"hyphen"` (default), `"minus"` for a proper Unicode minus symbol or
 #'   `"parens"` to wrap the number in parentheses.
+#' @param decimal_point Character string containing a single character that
+#'   is used as decimal point in output conversions.
 #' @param ... Arguments passed to or from other methods.
 #'
 #'
@@ -44,16 +46,17 @@
 #' format_value(1.2)
 #' format_value(1.2012313)
 #' format_value(c(0.0045, 234, -23))
-#' format_value(c(0.0045, .12, .34))
-#' format_value(c(0.0045, .12, .34), as_percent = TRUE)
-#' format_value(c(0.0045, .12, .34), digits = "scientific")
-#' format_value(c(0.0045, .12, .34), digits = "scientific2")
-#' format_value(c(0.045, .12, .34), lead_zero = FALSE)
+#' format_value(c(0.0045, 0.12, 0.34))
+#' format_value(c(0.0045, 0.12, 0.34), as_percent = TRUE)
+#' format_value(c(0.0045, 0.12, 0.34), digits = "scientific")
+#' format_value(c(0.0045, 0.12, 0.34), digits = "scientific2")
+#' format_value(c(0.045, 0.12, 0.34), lead_zero = FALSE)
+#' format_value(c(0.0045, 0.12, 0.34), decimal_point = ",")
 #'
 #' # default
-#' format_value(c(0.0045, .123, .345))
+#' format_value(c(0.0045, 0.123, 0.345))
 #' # significant figures
-#' format_value(c(0.0045, .123, .345), digits = "signif")
+#' format_value(c(0.0045, 0.123, 0.345), digits = "signif")
 #'
 #' format_value(as.factor(c("A", "B", "A")))
 #' format_value(iris$Species)
@@ -80,6 +83,7 @@ format_value.data.frame <- function(x,
                                     lead_zero = TRUE,
                                     style_positive = "none",
                                     style_negative = "hyphen",
+                                    decimal_point = getOption("OutDec"),
                                     ...) {
   as.data.frame(sapply(
     x,
@@ -93,6 +97,7 @@ format_value.data.frame <- function(x,
     lead_zero = lead_zero,
     style_positive = style_positive,
     style_negative = style_negative,
+    decimal_point = decimal_point,
     simplify = FALSE
   ))
 }
@@ -110,10 +115,11 @@ format_value.numeric <- function(x,
                                  lead_zero = TRUE,
                                  style_positive = "none",
                                  style_negative = "hyphen",
+                                 decimal_point = getOption("OutDec"),
                                  ...) {
   # check input
-  style_positive <- match.arg(style_positive, choices = c("none", "plus", "space"))
-  style_negative <- match.arg(style_negative, choices = c("hyphen", "minus", "parens"))
+  style_positive <- validate_argument(style_positive, c("none", "plus", "space"))
+  style_negative <- validate_argument(style_negative, c("hyphen", "minus", "parens"))
 
   if (protect_integers) {
     out <- .format_value_unless_integer(
@@ -167,6 +173,11 @@ format_value.numeric <- function(x,
     } else if (style_negative == "parens") {
       out[negatives] <- gsub("-(.*)", "\\(\\1\\)", out[negatives])
     }
+
+    # decimal points
+    if (!is.null(decimal_point) && !identical(decimal_point, ".")) {
+      out <- gsub(".", decimal_point, out, fixed = TRUE)
+    }
   }
 
   out
@@ -224,7 +235,13 @@ format_percent <- function(x, ...) {
 
 
 
-.format_value <- function(x, digits = 2, .missing = "", .width = NULL, .as_percent = FALSE, .zap_small = FALSE, ...) {
+.format_value <- function(x,
+                          digits = 2,
+                          .missing = "",
+                          .width = NULL,
+                          .as_percent = FALSE,
+                          .zap_small = FALSE,
+                          ...) {
   # proper character NA
   if (is.na(.missing)) .missing <- NA_character_
 
@@ -248,9 +265,7 @@ format_percent <- function(x, ...) {
       }
     } else if (is.character(digits) && grepl("scientific", digits, fixed = TRUE)) {
       digits <- tryCatch(
-        expr = {
-          as.numeric(gsub("scientific", "", digits, fixed = TRUE))
-        },
+        as.numeric(gsub("scientific", "", digits, fixed = TRUE)),
         error = function(e) {
           5
         }
@@ -259,9 +274,7 @@ format_percent <- function(x, ...) {
       x <- sprintf("%.*e", digits, x)
     } else if (is.character(digits) && grepl("signif", digits, fixed = TRUE)) {
       digits <- tryCatch(
-        expr = {
-          as.numeric(gsub("signif", "", digits, fixed = TRUE))
-        },
+        as.numeric(gsub("signif", "", digits, fixed = TRUE)),
         error = function(e) {
           NA
         }
