@@ -8,18 +8,22 @@
 #' @inheritParams find_parameters
 #' @inheritParams find_predictors
 #'
+#' @inheritSection find_predictors Model components
+#'
 #' @return A data frame with three columns: the parameter names, the related
 #'   point estimates and the component.
 #'
-#' @examples
-#' data(mtcars)
-#' m <- lm(mpg ~ wt + cyl + vs, data = mtcars)
+#' @examplesIf requireNamespace("betareg", quietly = TRUE)
+#' data("GasolineYield", package = "betareg")
+#' m <- betareg::betareg(yield ~ batch + temp, data = GasolineYield)
 #' get_parameters(m)
+#' get_parameters(m, component = "precision")
 #' @export
-get_parameters.betareg <- function(x,
-                                   component = c("all", "conditional", "precision", "location", "distributional", "auxiliary"),
-                                   ...) {
-  component <- match.arg(component)
+get_parameters.betareg <- function(x, component = "all", ...) {
+  component <- validate_argument(
+    component,
+    c("all", "conditional", "precision", "location", "distributional", "auxiliary")
+  )
   cf <- stats::coef(x)
 
   params <- data.frame(
@@ -38,10 +42,9 @@ get_parameters.betareg <- function(x,
 }
 
 
-#' @rdname get_parameters.betareg
 #' @export
-get_parameters.glmgee <- function(x, component = c("all", "conditional", "dispersion"), ...) {
-  component <- match.arg(component)
+get_parameters.glmgee <- function(x, component = "all", ...) {
+  component <- validate_argument(component, c("all", "conditional", "dispersion"))
 
   junk <- utils::capture.output({
     cs <- suppressWarnings(stats::coef(summary(x, corr = FALSE)))
@@ -97,12 +100,12 @@ get_parameters.nestedLogit <- function(x, component = "all", verbose = TRUE, ...
 }
 
 
-#' @rdname get_parameters.betareg
 #' @export
-get_parameters.DirichletRegModel <- function(x,
-                                             component = c("all", "conditional", "precision", "location", "distributional", "auxiliary"),
-                                             ...) {
-  component <- match.arg(component)
+get_parameters.DirichletRegModel <- function(x, component = "all", ...) {
+  component <- validate_argument(
+    component,
+    c("all", "conditional", "precision", "location", "distributional", "auxiliary")
+  )
   cf <- stats::coef(x)
 
   if (x$parametrization == "common") {
@@ -137,12 +140,9 @@ get_parameters.DirichletRegModel <- function(x,
 }
 
 
-#' @rdname get_parameters.betareg
 #' @export
-get_parameters.averaging <- function(x,
-                                     component = c("conditional", "full"),
-                                     ...) {
-  component <- match.arg(component)
+get_parameters.averaging <- function(x, component = "conditional", ...) {
+  component <- validate_argument(component, c("conditional", "full"))
   cf <- stats::coef(x, full = component == "full")
 
   params <- data.frame(
@@ -156,12 +156,12 @@ get_parameters.averaging <- function(x,
 }
 
 
-#' @rdname get_parameters.betareg
 #' @export
-get_parameters.glmx <- function(x,
-                                component = c("all", "conditional", "extra", "location", "distributional", "auxiliary"),
-                                ...) {
-  component <- match.arg(component)
+get_parameters.glmx <- function(x, component = "all", ...) {
+  component <- validate_argument(
+    component,
+    c("all", "conditional", "extra", "location", "distributional", "auxiliary")
+  )
   cf <- stats::coef(summary(x))
 
   params <- rbind(
@@ -189,12 +189,9 @@ get_parameters.glmx <- function(x,
 }
 
 
-#' @rdname get_parameters.betareg
 #' @export
-get_parameters.clm2 <- function(x,
-                                component = c("all", "conditional", "scale"),
-                                ...) {
-  component <- match.arg(component)
+get_parameters.clm2 <- function(x, component = "all", ...) {
+  component <- validate_argument(component, c("all", "conditional", "scale"))
 
   cf <- stats::coef(summary(x))
   n_intercepts <- length(x$xi)
@@ -221,12 +218,12 @@ get_parameters.clm2 <- function(x,
 get_parameters.clmm2 <- get_parameters.clm2
 
 
-#' @rdname get_parameters.betareg
 #' @export
-get_parameters.mvord <- function(x,
-                                 component = c("all", "conditional", "thresholds", "correlation"),
-                                 ...) {
-  component <- match.arg(component)
+get_parameters.mvord <- function(x, component = "all", ...) {
+  component <- validate_argument(
+    component,
+    c("all", "conditional", "thresholds", "correlation")
+  )
   junk <- utils::capture.output(s <- summary(x)) # nolint
   # intercepts thresholds
   thresholds <- as.data.frame(s$thresholds)
@@ -276,13 +273,9 @@ get_parameters.mvord <- function(x,
 }
 
 
-
-#' @rdname get_parameters.betareg
 #' @export
-get_parameters.mjoint <- function(x,
-                                  component = c("all", "conditional", "survival"),
-                                  ...) {
-  component <- match.arg(component)
+get_parameters.mjoint <- function(x, component = "all", ...) {
+  component <- validate_argument(component, c("all", "conditional", "survival"))
   s <- summary(x)
 
   params <- rbind(
@@ -310,11 +303,10 @@ get_parameters.mjoint <- function(x,
 }
 
 
-
 #' @export
 get_parameters.systemfit <- function(x, ...) {
   cf <- stats::coef(summary(x))
-  f <- find_formula(x)
+  f <- find_formula(x, verbose = FALSE)
 
   system_names <- names(f)
   parameter_names <- row.names(cf)
@@ -333,6 +325,7 @@ get_parameters.systemfit <- function(x, ...) {
   do.call(rbind, out)
 }
 
+
 #' @export
 get_parameters.marginaleffects <- function(x, summary = FALSE, merge_parameters = FALSE, ...) {
   # check if we have a Bayesian model here
@@ -421,3 +414,39 @@ get_parameters.ggcomparisons <- function(x, merge_parameters = FALSE, ...) {
   }
   text_remove_backticks(out)
 }
+
+
+#' @export
+get_parameters.coxph <- function(x, verbose = TRUE, ...) {
+  cf <- stats::coef(summary(x))
+  params <- rownames(cf)
+  if (is.null(params)) {
+    params <- paste(seq_along(cf))
+  }
+
+  params <- data.frame(
+    Parameter = params,
+    Estimate = unname(cf[, 1]),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  text_remove_backticks(params)
+}
+
+
+#' @export
+get_parameters.asym <- function(x, verbose = TRUE, ...) {
+  cf <- stats::coef(x)
+  params <- data.frame(
+    Parameter = names(cf),
+    Estimate = unname(cf),
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  params$Parameter <- gsub("^plus__", "+", params$Parameter)
+  params$Parameter <- gsub("^minus__", "-", params$Parameter)
+
+  text_remove_backticks(params)
+}
