@@ -8,6 +8,8 @@
 #' @inheritParams find_parameters
 #' @inheritParams find_predictors
 #'
+#' @inheritSection find_predictors Model components
+#'
 #' @return For models with smooth terms or zero-inflation component, a data
 #'   frame with three columns: the parameter names, the related point estimates
 #'   and the component.
@@ -17,10 +19,8 @@
 #' m <- lm(mpg ~ wt + cyl + vs, data = mtcars)
 #' get_parameters(m)
 #' @export
-get_parameters.zeroinfl <- function(x,
-                                    component = c("all", "conditional", "zi", "zero_inflated"),
-                                    ...) {
-  component <- match.arg(component)
+get_parameters.zeroinfl <- function(x, component = "all", ...) {
+  component <- validate_argument(component, c("all", "conditional", "zi", "zero_inflated"))
   .return_zeroinf_parms(x, component)
 }
 
@@ -31,12 +31,9 @@ get_parameters.hurdle <- get_parameters.zeroinfl
 get_parameters.zerotrunc <- get_parameters.default
 
 
-#' @rdname get_parameters.zeroinfl
 #' @export
-get_parameters.zcpglm <- function(x,
-                                  component = c("all", "conditional", "zi", "zero_inflated"),
-                                  ...) {
-  component <- match.arg(component)
+get_parameters.zcpglm <- function(x, component = "all", ...) {
+  component <- validate_argument(component, c("all", "conditional", "zi", "zero_inflated"))
   cf <- stats::coef(x)
 
   cond <- data.frame(
@@ -78,8 +75,8 @@ get_parameters.zcpglm <- function(x,
 .return_zeroinf_parms <- function(x, component) {
   cf <- stats::coef(x)
 
-  conditional <- grepl("^count_", names(cf), perl = TRUE)
-  zero_inflated <- grepl("^zero_", names(cf), perl = TRUE)
+  conditional <- startsWith(names(cf), "count_")
+  zero_inflated <- startsWith(names(cf), "zero_")
 
   cond <- data.frame(
     Parameter = names(cf)[conditional],
@@ -112,19 +109,20 @@ get_parameters.zcpglm <- function(x,
 }
 
 
-
-
-#' @rdname get_parameters.zeroinfl
 #' @export
-get_parameters.mhurdle <- function(x,
-                                   component = c("all", "conditional", "zi", "zero_inflated", "infrequent_purchase", "ip", "auxiliary"),
-                                   ...) {
-  component <- match.arg(component)
+get_parameters.mhurdle <- function(x, component = "all", ...) {
+  component <- validate_argument(
+    component,
+    c(
+      "all", "conditional", "zi", "zero_inflated",
+      "infrequent_purchase", "ip", "auxiliary"
+    )
+  )
   cf <- stats::coef(x)
 
-  cond_pars <- which(grepl("^h2\\.", names(cf)))
-  zi_pars <- which(grepl("^h1\\.", names(cf)))
-  ip_pars <- which(grepl("^h3\\.", names(cf)))
+  cond_pars <- which(startsWith(names(cf), "h2."))
+  zi_pars <- which(startsWith(names(cf), "h1."))
+  ip_pars <- which(startsWith(names(cf), "h3."))
   aux_pars <- (seq_along(names(cf)))[-c(cond_pars, zi_pars, ip_pars)]
 
   if (length(cond_pars)) {
