@@ -15,7 +15,7 @@
   }
 
   if (is.null(newdata)) {
-    newdata <- get_data(model)
+    newdata <- get_data(model, verbose = FALSE)
   }
 
   if (is.null(nsim)) {
@@ -47,7 +47,7 @@
 
 
   # We need to fix a bit here. We have the simulated standard errors and CI's -
-  # but can use the "correct" predictions from "predict(type = "reponse")".
+  # but can use the "correct" predictions from "predict(type = "response")".
   # in order to make CI and predictions match, we take the simulated CI-range
   # and use the original predicted values as "center" for those CI-ranges.
 
