@@ -213,7 +213,7 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
       dat <- as.data.frame(x)
       sigma_column <- grep("sigma", colnames(dat), fixed = TRUE)
       if (length(sigma_column) == 1) {
-        mean(dat[[sigma_column]][1])
+        mean(dat[[sigma_column]])
       } else if (length(sigma_column)) {
         # if more than one sigma column,
         # there isn't a traditional sigma for the model
@@ -226,7 +226,6 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
       NULL
     }
   )
-
   # compute sigma manually ---------------
   if (is_empty_object(s)) {
     # default sigma ---------------
