@@ -194,6 +194,22 @@ get_statistic.merModList <- function(x, ...) {
 }
 
 
+#' @export
+get_statistic.asym <- function(x, ...) {
+  cftable <- summary(x)$coef_table
+  out <- data.frame(
+    Parameter = find_parameters(x)$conditional,
+    Statistic = cftable[, "t val."],
+    stringsAsFactors = FALSE,
+    row.names = NULL
+  )
+
+  out <- text_remove_backticks(out)
+  attr(out, "statistic") <- find_statistic(x)
+  out
+}
+
+
 #' @export
 get_statistic.afex_aov <- function(x, ...) {
   out <- data.frame(
@@ -2092,7 +2108,7 @@ get_statistic.rqss <- function(x,
 #' @export
 get_statistic.systemfit <- function(x, ...) {
   cf <- stats::coef(summary(x))
-  f <- find_formula(x)
+  f <- find_formula(x, verbose = FALSE)
 
   system_names <- names(f)
   parameter_names <- row.names(cf)
