@@ -2,25 +2,24 @@
 #' @name get_varcov
 #'
 #' @description
-#'
 #' Returns the variance-covariance, as retrieved by `stats::vcov()`, but works
 #' for more model objects that probably don't provide a `vcov()`-method.
 #'
 #'
 #' @param x A model.
 #' @param component Should the complete variance-covariance matrix of the model
-#'   be returned, or only for specific model components only (like count or
-#'   zero-inflated model parts)? Applies to models with zero-inflated component,
-#'   or models with precision (e.g. `betareg`) component. `component` may be one
-#'   of `"conditional"`, `"zi"`, `"zero-inflated"`, `"dispersion"`,
-#'   `"precision"`, or `"all"`. May be abbreviated. Note that the *conditional*
-#'   component is also called *count* or *mean* component, depending on the
-#'   model.
+#' be returned, or only for specific model components only (like count or
+#' zero-inflated model parts)? Applies to models with zero-inflated component,
+#' or models with precision (e.g. `betareg`) component. `component` may be one
+#' of `"conditional"`, `"zi"`, `"zero-inflated"`, `"dispersion"`, `"precision"`,
+#' or `"all"`. May be abbreviated. Note that the *conditional* component also
+#' refers to the *count* or *mean* component - names may differ, depending on
+#' the modeling package.
 #' @param effects Should the complete variance-covariance matrix of the model
-#'   be returned, or only for specific model parameters only? Currently only
-#'   applies to models of class `mixor`.
+#' be returned, or only for specific model parameters only? Currently only
+#' applies to models of class `mixor`.
 #' @param complete Logical, if `TRUE`, for `aov`, returns the full
-#'   variance-covariance matrix.
+#' variance-covariance matrix.
 #' @param vcov Variance-covariance matrix used to compute uncertainty estimates
 #' (e.g., for robust standard errors). This argument accepts a covariance
 #' matrix, a function which returns a covariance matrix, or a string which
@@ -28,21 +27,23 @@
 #'  * A covariance matrix
 #'  * A function which returns a covariance matrix (e.g., `stats::vcov()`)
 #'  * A string which indicates the kind of uncertainty estimates to return.
-#'    - Heteroskedasticity-consistent: `"vcovHC"`, `"HC"`, `"HC0"`, `"HC1"`,
-#'      `"HC2"`, `"HC3"`, `"HC4"`, `"HC4m"`, `"HC5"`. See `?sandwich::vcovHC`
-#'    - Cluster-robust: `"vcovCR"`, `"CR0"`, `"CR1"`, `"CR1p"`, `"CR1S"`,
-#'      `"CR2"`, `"CR3"`. See `?clubSandwich::vcovCR()`
-#'    - Bootstrap: `"vcovBS"`, `"xy"`, `"residual"`, `"wild"`, `"mammen"`,
-#'      `"webb"`. See `?sandwich::vcovBS`
-#'    - Other `sandwich` package functions: `"vcovHAC"`, `"vcovPC"`, `"vcovCL"`,
-#'      `"vcovPL"`.
+#'    - Heteroskedasticity-consistent: `"HC"`, `"HC0"`, `"HC1"`, `"HC2"`,
+#'      `"HC3"`, `"HC4"`, `"HC4m"`, `"HC5"`. See `?sandwich::vcovHC`
+#'    - Cluster-robust: `"CR"`, `"CR0"`, `"CR1"`, `"CR1p"`, `"CR1S"`, `"CR2"`,
+#'      `"CR3"`. See `?clubSandwich::vcovCR`
+#'    - Bootstrap: `"BS"`, `"xy"`, `"residual"`, `"wild"`, `"mammen"`,
+#'      `"fractional"`, `"jackknife"`, `"norm"`, `"webb"`. See
+#'      `?sandwich::vcovBS`
+#'    - Other `sandwich` package functions: `"HAC"`, `"PC"`, `"CL"`, `"OPG"`,
+#'      `"PL"`.
+#'    - Kenward-Roger approximation: `kenward-roger`. See `?pbkrtest::vcovAdj`.
 #' @param vcov_args List of arguments to be passed to the function identified by
-#'   the `vcov` argument. This function is typically supplied by the **sandwich**
-#'   or **clubSandwich** packages. Please refer to their documentation (e.g.,
-#'   `?sandwich::vcovHAC`) to see the list of available arguments. If no estimation
-#'   type (argument `type`) is given, the default type for `"HC"` (or `"vcovHC"`)
-#'   equals the default from the **sandwich** package; for type `"CR"` (or
-#'   `"vcoCR"`), the default is set to `"CR3"`.
+#'   the `vcov` argument. This function is typically supplied by the
+#'   **sandwich** or **clubSandwich** packages. Please refer to their
+#'   documentation (e.g., `?sandwich::vcovHAC`) to see the list of available
+#'   arguments. If no estimation type (argument `type`) is given, the default
+#'   type for `"HC"` equals the default from the **sandwich** package; for type
+#'   `"CR"`, the default is set to `"CR3"`.
 #' @param verbose Toggle warnings.
 #' @param ... Currently not used.
 #'
@@ -133,6 +134,16 @@ get_varcov.fixest <- function(x,
 }
 
 
+#' @export
+get_varcov.asym <- function(x, ...) {
+  out <- get_varcov.default(x, ...)
+  colnames(out) <- gsub("^plus__", "+", colnames(out))
+  rownames(out) <- gsub("^plus__", "+", rownames(out))
+  colnames(out) <- gsub("^minus__", "-", colnames(out))
+  rownames(out) <- gsub("^minus__", "-", rownames(out))
+  out
+}
+
 
 # mlm ---------------------------------------------
 
@@ -1172,6 +1183,9 @@ get_varcov.LORgee <- get_varcov.gee
       sprintf("The `vcov` argument of the `insight::get_varcov()` function is not yet supported for models of class `%s`.", paste(class(x), collapse = "/")) # nolint
     )
   }
+  if ("robust" %in% names(dots) && !is.null(dots[["robust"]])) {
+    format_warning("The `robust` argument is no longer supported. Please use the `vcov` and `vcov_args` instead.") # nolint
+  }
 }
 
 
@@ -1182,16 +1196,5 @@ get_varcov.LORgee <- get_varcov.gee
   if (is.null(vcov) && "vcov_estimation" %in% names(dots)) {
     vcov <- dots[["vcov_estimation"]]
   }
-
-  if ("robust" %in% names(dots)) {
-    # default robust covariance
-    if (is.null(vcov)) {
-      vcov <- "HC3"
-    }
-    if (isTRUE(verbose)) {
-      format_warning("The `robust` argument is deprecated. Please use `vcov` instead.")
-    }
-  }
-
   vcov
 }
