@@ -284,7 +284,7 @@
   # that are not covered by the standard elements. We then just do not
   # filter elements.
   if (inherits(model, "brmsfit") && component == "all") {
-    f <- insight::find_formula(model)
+    f <- insight::find_formula(model, verbose = FALSE)
     elements <- unique(c(elements, names(f)))
   }
 
@@ -364,29 +364,13 @@
 
 
 .grep_zi_smoothers <- function(x) {
-  grepl("^(s\\.\\d\\()", x, perl = TRUE) |
-    grepl("^(gam::s\\.\\d\\()", x, perl = TRUE) |
-    grepl("^(mgcv::s\\.\\d\\()", x, perl = TRUE)
+  # this one captures smoothers in zi- or mv-models from gam
+  grepl("^(s\\.\\d\\()", x) | grepl("^(gam::s\\.\\d\\()", x) | grepl("^(mgcv::s\\.\\d\\()", x)
 }
 
 
 .grep_non_smoothers <- function(x) {
-  grepl("^(?!(s\\())", x, perl = TRUE) &
-    # this one captures smoothers in zi- or mv-models from gam
-    grepl("^(?!(s\\.\\d\\())", x, perl = TRUE) &
-    grepl("^(?!(ti\\())", x, perl = TRUE) &
-    grepl("^(?!(te\\())", x, perl = TRUE) &
-    grepl("^(?!(t2\\())", x, perl = TRUE) &
-    grepl("^(?!(gam::s\\())", x, perl = TRUE) &
-    grepl("^(?!(gam::s\\.\\d\\())", x, perl = TRUE) &
-    grepl("^(?!(VGAM::s\\())", x, perl = TRUE) &
-    grepl("^(?!(mgcv::s\\())", x, perl = TRUE) &
-    grepl("^(?!(mgcv::s\\.\\d\\())", x, perl = TRUE) &
-    grepl("^(?!(mgcv::ti\\())", x, perl = TRUE) &
-    grepl("^(?!(mgcv::te\\())", x, perl = TRUE) &
-    grepl("^(?!(brms::s\\())", x, perl = TRUE) &
-    grepl("^(?!(brms::t2\\())", x, perl = TRUE) &
-    grepl("^(?!(smooth_sd\\[))", x, perl = TRUE)
+  !.grep_smoothers(x) & !.grep_zi_smoothers(x)
 }
 
 
